#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYHOUS.DO                V : 01            *
*    Date    : 29 NOV 2004                                  *
*    Infile  : SECTION1, HHYREG                             *
*    Outfile : HHXHOUS, HHYHOUS                             *
*                                                           *
*    OBJECTIVE: Calculate Imputed Housing Income AND        *
*               Housing Expenditure                         *
*                                                           *
*************************************************************;;

global IN ="c:\data\kids3\version1.1" ;
global OUT="c:\data\kids3\version1.1\constructed" ;
   

** IMPORTANT NOTE: Must run CLCYREG.DO before running this program      **
** CLCYREG.DO calculates the value of the housing subsidy/allowance     **
** received (monthhse) which is used in this program                    **;;


use $IN\section2.dta, clear ;   

rename cluster clustnum;


** VERIFY that everyone either owns, rents, lives rent free             **;;

** Owners                                                               **;;

** List those who report owning house but missing or low house value    **;

li hhid2004 ownship_ sale_val bond bond_owe if ownship_==1 & sale_val < 200 & sale_val>0;;

**  NOTE 1: looks OK                                                    **;;

** List those who report paying rent but rent amount is missing   **;;

li hhid2004 pay_rent rent_mkt rent_act if pay_rent== 1 & rent_act < 1 ;;

**  NOTE 2: 1 household reported N/A for ACTUAL rent.  Impute    **;;

* List those who report rent-free and not rent amount estimated (Q9c)   **;;

li hhid2004 pay_rent rent_mkt rent_act if pay_rent== 2 & rent_mkt < 1 ;;

**  NOTE 3: 7 households reported DNK for MARKET rent.  Impute    **;;

*-----------------------------------------------------------------------*
* Rent                                                                  *
*-----------------------------------------------------------------------*;;

** Combine market and estimated rent                                    **;;

gen     rentval = rent_act if rent_act > 0;
replace rentval = rent_mkt if rent_mkt > 0;

** Construct cluster medians for positive values                        **;;

egen tmprent = median(rentval)  if rentval  > 0, by(clustnum) ;
egen tmphous = median(sale_val) if sale_val > 0, by(clustnum) ;

egen medrent = median(tmprent), by(clustnum) ;
egen medhous = median(tmphous), by(clustnum) ;
drop tmprent tmphous ;

** Construct flag 0/1/2 to indicate missing values                      **;;

gen     flagrent =      (pay_rent== 1     & rent_act <  1) ;  
replace flagrent =  2 * (pay_rent== 2     & rent_mkt <  1)  if flagrent == 0 ;  
replace flagrent =  3 * (ownship_ == 1 & sale_val < 10)  if flagrent == 0 ; 

li hhid2004 medrent if flagrent == 1 | flagrent == 2 ;
li hhid2004 medhous if flagrent == 3 ;

** Replace missing observations with cluster medians             **;;

replace rentval  = medrent if flagrent == 1 ;
replace rentval  = medrent if flagrent == 2 ;
replace sale_val = medhous if flagrent == 3 ;  

** Household 1930080 is the only HH in cluster that does not own home   **
** Assume a market rent of 13% p.a. of median house value in cluster    **
** (60000 * 0.13 / 12)                                                  **;;

replace rentval = 650 if hhid2004 == 1930080 & rentval==. ;     

** Reset flagrent to 0/1                                                **;;

replace flagrent = 1 if flagrent > 1 ;


*-----------------------------------------------------------------------*
* Imputed Income from owner occupied housing                            *
*-----------------------------------------------------------------------*;;

** Calculate imputed income from housing defined as the rental value    **
** of housing assets net of bond owed using a 13% return.               **
** This is the median from S7.2 (Property File) in Saldru 1993          **
** Note: no corresponding section appears in 1998                       **;;

**  Verify that bond/mortgage outstanding is less than property value   **;;

li hhid2004 ownship_ sale_val bond bond_owe
        if sale_val <= bond_owe & sale_val > 0 & bond_owe ~= . ;;

**  Only 1 case, replace net value with zero to avoid imputed loss      **
**  on housing. Also 1 case where bond and value are equal              **;
                                  
replace bond_owe = 0 if bond == 2 ; * Change from valid missing = -1 *;

gen     netvalu = 0 ;
replace netvalu = sale_val - bond_owe if sale_val > 0 & bond_owe >= 0 ;
replace netvalu = sale_val            if sale_val > 0 & bond_owe <  0  ;
replace netvalu = 0 if netvalu < 0;   

gen     rentimp = netvalu * 0.13/12 ;   
replace rentimp = . if rentval ~= . ;

** Conceptual Issue: While it makes sense to calculate the "income"     **
** from owner occupied housing to be the rate of return on only that    **
** part owned (sale_val - bond_owe) when calculating the expenditure    **
** one should do this on the total value, unless the financing expenses **
** are included elsewhere in the expenditures and they were not asked   **
** about explicitly                                                     **;;

** Therefore, calculate rentimpx on this basis for the expenditure file **;;

gen     rentimpx = sale_val * 0.13/12 ;   
replace rentimpx = . if rentval ~= . ;

sort hhid2004;
save $OUT\step1, replace;  


** Note: All households now have a value for rentval (actual or market) **
**       or rentimp (imputed from housing value)                        **;;

** Housing subsidies constructed in CLCYREG.DO & stored in HHYREG       **;;

use $OUT\hhyreg , clear ;
keep hhid2004 monthhse ;
sort hhid2004;               
merge hhid2004 using $OUT\step1 ;

recode monthh .=0;

** NOTE: These calculations are made assuming housing subsidies not     **
**       made in cash. See notes for problems when they are (8 obs)     **;

** There are three cases to consider                                    **;

** (1) Household pays rent and also receives housing subsidy            **
** Add the paid rent and housing subsidy                                **;;

li rentval rent_act monthhse flag     if rent_act > 0 & monthhse > 0  ;

replace rentval = rent_act + monthhse if rent_act > 0 & monthhse > 0 ;


** (2) Household does not pay rent and specified market rent, but       **
** this is lower than housing subsidy received                          **
** Use the value of housing subsidy                                     **;;
   
li rentval rent_mkt monthhse flag if monthhse > rent_mkt & rent_mkt > 0 ;

replace rentval = monthhse        if monthhse > rent_mkt & rent_mkt > 0 ;

** (3) Household owns dwelling and receives subsidy in addition         **
** to imputed rent.  In this case, the subsidy is income and is added   **
** to income in CLCINCTL.DO, but does not affect expenditure on housing **
** So no change made                                                    **;;



*-----------------------------------------------------------------------*
* Housing expenditure (rent or owner occupied imputation)               *
*-----------------------------------------------------------------------*;;

gen     mxrent = rentimpx ;
replace mxrent = rentval if mxrent == . ;

gen byte source = 1 if rent_act ~= -1 ;
replace  source = 2 if rent_mkt ~= -1 ;
replace  source = 3 if source   ==  . ;      

label define source 1"Actual" 2"Market" 3"Owner" ;
label values source source ;

keep hhid2004 rent* flagrent mxrent source ;
sort hhid2004;

** Label variables                                                      **;;

label data "2004 (Imputed) Housing Expenditure";

label var rentimpx "04: Month exp Impute own-occ rent";
label var rentimp  "04: Month income Impute own-occ rent";
label var rentval  "04: Month exp Impute not-own rent" ;
label var mxrent   "04: Month exp Impute housing";
label var source   "04: Housing/Rent exp source" ;
label var flagrent "04: (1) if rent/hse val imputed" ;

notes drop _dta ;
notes : Calculations assume housing subsidy paid in kind ;

sort hhid2004 ;
save $OUT\hhxhous, replace;     

*-----------------------------------------------------------------------*
* Housing Income (owner occupied imputation)                            *
*-----------------------------------------------------------------------*;;

keep hhid2004 rentimp flagrent ;

rename  flagrent flagval ;
replace flagval = 0 if rentimp == . ;

replace rentimp = 0 if rentimp == .|rentimp<0 ;

label var flagval "04: (1) if hse val imputed" ;
label data "2004 (Imputed) Income from Housing";

order hhid2004 rentimp flag ;

sort hhid2004 ;
save $OUT\hhyhous, replace;

desc ;
summ ;

use $OUT\hhxhous, clear ;
drop rentimp ;

recode rentval .=0;
recode rentimp .=0;

order hhid2004 rent_act rent_mkt rentval rentimp mxrent source flag ;
sort hhid2004 ;
save $OUT\hhxhous, replace ;

desc ;
summ ;

erase $OUT\step1.dta ;

exit ;


