#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYREG.DO               V : 01              *
*    Date    : 21 NOV 2004                                  *
*    Infile  : SECTION 9.2                                  *
*    Outfiles: YREG, HHYREG                                 *
*                                                           *
*    OBJECTIVE: Calculate wage income from regular          *
*               employment (Section 10.2)                   *
*                                                           *
*               NOTE: There are a large number of           *
*               imputations made in this program and they   *
*               rely on many assumptions.  Read program     *
*               carefully before using.                     *
*                                                           *
*               Calculate Average Monthly Gross and/or Net  *
*               pay for individuals (YREG) and HHs (HHYREG) *
*                1) if only one of the two is recorded,     *
*                impute other with average tax ratio        *
*                2) If neither recorded, impute NET with    *
*                simple wage equation regression            *
*                3) Program also contains code to impute    *
*                NET via medians as done in 1993 (but       *
*                not saved)                                 *
*                                                           *
*               Calculate average monthly bonuses, profit   *
*               share and subsidy values.                   *
*                                                           *
*                                                           *
*************************************************************;;

global IN   ="c:\data\kids3\version1.1" ;
global OUT  ="c:\data\kids3\version1.1\constructed" ;

program drop _all;

use $IN\section9_2.dta, clear ;  

drop if pcode<0;

*-----------------------------------------------------------------------*
* Net and Gross Pay                                                     *
*-----------------------------------------------------------------------*;;

**  Calculate Net and Gross monthly earnings                            **
**  Multiplication factors for weekly and bi-weekly applied             **;;

global week   = 4.30 ;
global fortnt = 2.15 ;
global day    = 22;

gen     mnetpay = p_netpay           if p_paytyp == 3 & p_netpay > 0 ;
replace mnetpay = p_netpay * $day    if p_paytyp == 4 & p_netpay > 0 ;
replace mnetpay = p_netpay * $fortnt if p_paytyp == 2 & p_netpay > 0 ;
replace mnetpay = p_netpay * $week   if p_paytyp == 1 & p_netpay > 0 ;


gen     mgrspay = p_grossp           if p_paytyp == 3 & p_grossp > 0 ;
replace mgrspay = p_grossp * $day    if p_paytyp == 4 & p_grossp > 0 ;
replace mgrspay = p_grossp * $fortnt if p_paytyp == 2 & p_grossp > 0 ;
replace mgrspay = p_grossp * $week   if p_paytyp == 1 & p_grossp > 0 ;

label var mnetpay "04: Monthly net pay";
label var mgrspay "04: Monthly gross pay";

sort hhid2004 pcode;  
save $OUT\yreg, replace; 

** The following section examines the relationship between gross and
   net when both are available.  It then calculates "tax ratios" for
   quartiles of net pay and uses these to impute missing net pay when
   gross pay is available and vice versa                                **;;

gen net_gr = mnetpay / mgrspay ;
sum net_gr, det; drop net_gr ;

** Based on those observations for which both gross and net pay         **
** are available, net is approximately 78% of gross.                    **
** Note : In 1993 (1998) imputations, this figure was 90% (80%)         **;;

keep hhid2004 pcode mnetpay mgrspay ;
drop if mnetpay==. & mgrspay==. ;   

** Now calculate the median tax rates for each quartile of net pay      **
** then merge them back in to allow calculations                        **;;

sort mnetpay ;
gen rank=group(4) ;
sort rank ;
save $OUT\step1,replace; 

drop if mnetpay==. | mgrspay==.;  
gen taxratio = mnetpay / mgrspay ;
egen ratmed  = median(taxratio), by(rank) ;
drop mnetpay mgrspay taxratio hhid2004 pcode ;

sort rank;
merge rank using $OUT\step1 ;
assert _merge==3 ;
drop _merge mnetpay mgrspay rank ;

sort hhid2004 pcode ; 
merge hhid2004 pcode using $OUT\yreg ;
assert _merge==2 | _merge==3 ;
drop _merge ;

** Impute missing net and gross pay figures using median tax ratio      **
** from the quartile                                                    **;;

gen byte flagnet = (mnetpay == . & mgrspay ~= . ) ;
gen byte flaggrs = (mnetpay ~= . & mgrspay == . ) ;
replace mnetpay  =  mgrspay * ratmed if flagnet ;
replace mgrspay  =  mnetpay / ratmed if flaggrs ;

label var flagnet "04:(1)Net pay imputed:tx ratio" ;
label var flaggrs "04:(1)Gross pay imputed:tx ratio" ;

sum mnetpay if mnetpay > 0;
sum mgrspay if mgrspay > 0;

notes drop _dta ;

sort hhid2004 pcode ;
save $OUT\yreg , replace ;      

*-----------------------------------------------------------------------*
* Benefits (Bonuses, Profit Share, Subsidies)                           *
*-----------------------------------------------------------------------*;;


** Calculate average monthly bonus for those reporting non-zero annual  **
** bonus.  Treat refusals and other missing as zero                     **;;

gen     monthbon = 0;
replace monthbon = p_bonus / 12 if p_bonus > 0 & p_bonus ~= .;
label var monthbon "04: Avg month bonus";

** Calculate average monthly transport subsidy for those reporting      **
** non-zero values.  Treat refusals and other missing as zero           **;;

gen     monthtvl = 0;
replace mgrspay = p_grossp * $fortnt if p_paytyp == 2 & p_grossp > 0 ;
replace monthtvl = subs_t * $fortnt if p_paytyp==2 & subs_t>0 & subs_t~=.;
replace monthtvl = subs_t * $week   if p_paytyp==1 & subs_t>0 & subs_t~=.;
replace monthtvl = subs_t * $day if p_paytyp==4 & subs_t>0 & subs_t~=.;
label var monthtvl "04: Avg month transport subsidy";

** Calculate average monthly food subsidy for those reporting non-zero   **
** values.  Treat refusals and other missing as zero                     **;

gen montheat=0;
replace montheat=subs_f           if p_paytyp==3 & subs_f>0 & subs_f~=.;
replace montheat=subs_f * $fortnt if p_paytyp==2 & subs_f>0 & subs_f~=.;
replace montheat=subs_f * $week   if p_paytyp==1 & subs_f>0 & subs_f~=.;
replace montheat=subs_f * $day    if p_paytyp==4 & subs_f>0 & subs_f~=.;
label var montheat "04: Avg month food subsidy";

** Calculate average monthly housing subsidy for those reporting        **
** non-zero values.  Treat refusals and other missing as zero           **;;


** The subsidy for housing appears too large in only 4 cases (subs_h)     **
** It jumps from R2000 to R22000 per month (3 cases)                               **
** In one case the subsidy per week is too large - worker earns R647 per week, but reports housing subsidy of
   R8050 per week.
** Treat those equal to or above R8050 as house VALUE rather than subsidies and      **
** assume a return of 13% p.a.  This is the median from Section 7.2     **
** (Property file) in Saldru 1993, no corresponding section in 1998     **;;

global hreturn = 0.13 ;

gen byte flaghse = ( subs_h >= 8050 ) ;

replace subs_h = subs_h * $hreturn / 12 if flaghse==1 ;

gen monthhse=0;
replace monthhse=subs_h            if flaghse == 1 ;
replace monthhse=subs_h            if p_paytyp==3 & subs_h>0 & subs_h~=. & flaghse==0;
replace monthhse=subs_h * $fortnt  if p_paytyp==2 & subs_h>0 & subs_h~=. & flaghse==0;
replace monthhse=subs_h * $week    if p_paytyp==1 & subs_h>0 & subs_h~=. & flaghse==0;
replace monthhse=subs_h * $day    if p_paytyp==4 & subs_h>0 & subs_h~=. & flaghse==0;

label var monthhse "04: Avg month housing subsidy";
label var flaghse "04: (1) if Hse subsidy imputed" ;

**   Construct Aggregate Wage Measures                                  **;

gen nwageinc = mnetpay + monthbon ;
label var nwageinc "04: Month Net Wage + Bonus" ; 

gen gwageinc = mgrspay + monthbon ;
label var gwageinc "04: Month Gross Wage + Bonus" ; 

** Construct 0/1 flag for observations missing BOTH net and gross pay   **;;

gen flagyreg = ( mnetpay==. ) ; 
label var flagyreg "04: (1) Net pay imputed:regn" ;

sort hhid2004 pcode;
save $OUT\yreg,replace;      
                     
** Fill in the missing values for the net wage that was refused or      **              
** do not know with imputed valued using (1) regression analysis or     **
** (2) medians of the hourly wage by occupation, race, and gender       **;;


** (1) Wage Regression                                                  **;;

** Replace missing hours with median = 8 hours                          **;

replace k_hours = 8 if k_hours < 1 ;
gen mnhours = 22 * k_hours ;

gen hourpay = 0 ;
replace hourpay = nwageinc/mnhours if k_hours > 0; 
sum hourpay if nwageinc > 0, det;

sort hhid2004 pcode ;
save $OUT\yreg , replace;

use $OUT\step1;
sort hhid2004 pcode;
save $OUT\step1, replace;

** Add age, gender and education variables                              **;;

use $IN\roster2004;
keep hhid2004 pcode age gender educ race;
merge hhid2004 pcode using $OUT\yreg ;
assert _merge==1 | _merge==3 ;
keep if _merge==3 ; drop _merge ;
sort hhid2004 pcode ;
save $OUT\step1, replace ;  

** Cleanup                                                              **;;

replace k_occ_co   = . if k_occ_co   < 0;
replace age     = . if age     < 0;
replace hourpay = . if hourpay < 0;

** For education, treat code=21 as 12 years of education                **;;

replace educ = 12 if educ == 21 ;
replace educ = .  if educ  < 0 | educ >= 17 ;

tab race,  gen(d_race);
tab k_occ_co, gen(d_occ) ;
gen fem    = (gender==0)   ;
gen age2 = age^2 ; 

gen lhour = log(hourpay) ;


reg    lhour age age2 educ fem d_race2 d_occ1-d_occ10 ;   
impute lhour age age2 educ fem d_race2 d_occ1-d_occ10, gen(i_lhour);

** Exponentiate the predicted log hourly wage                           **;;

gen i_hour=exp(i_lhour);
                        

** (2) Wage Medians                                                     **;

**  Calculate median wage values by Occupation, Race and gender         **;;

egen medhwage = median(hourpay) if hourpay > 0, by(k_occ_co race gender) ; 

** List original values with values obtained by (1) regression analysis **
** and (2) medians for comparison                                       **;;                                                     

format medhwage i_hour %5.2f;  

* Actual Net Wages *;;
tab k_occ_co race if flagyr==0, sum(hourpay) mean freq ;

* Actual Median Wages *;;
tab k_occ_co race if flagyr==0, sum(medhwage) mean freq ;

* Regression Imputed Net Wages for missing values *;;
tab k_occ_co race if flagyr==1, sum(i_hour) mean freq ;    

* Median Imputed Net Wages for missing values *;;
tab k_occ_co race if flagyr==1, sum(medhwage) mean freq ;


** Two imputed wages are calculated above and can be used for           **
** the missing values:                                                  **
** 1) The predicted values from the regression                          **
** 2) The median values by occupation, race and gender                  **;;

gen i_wage = i_hour * k_hours * 22 ; 
lab var i_wage "04: Regn imputed month wage";
sum i_wage if i_wage>0, det;   

gen medwage = medhwage * k_hours * 22; 
lab var medwage "04: Median imputed month wage";
sum medwage if medwage>0,det;

keep hhid2004 pcode medwage i_wage flagyreg ;

sort hhid2004 pcode;
merge hhid2004 pcode using $OUT\yreg ;
assert _merge == 3 ; drop _merge ;


** Missing values are replaced using the imputed regression estimates, **
** the median imputed values are available in the yreg file for all    **
** the researchers that would prefer to use them                       **;;

replace nwageinc = i_wage if flagyreg ;

sum nwageinc if flagyreg==0 ;
sum nwageinc if flagyreg==1 ;

** Cleanup                                                              **;;

lab data "2004 Individual Regular Wage Income";

notes drop _dta ;                              

sort hhid2004 pcode ;
save $OUT\yreg, replace ;    

* This completes construction of individual level wage income file, YREG *
*------------------------------------------------------------------------*;

** Construct household level wage income file, HHYREG                  **;;

collapse (sum) hhnwage=nwageinc hhgwage=gwageinc
               flag* monthtvl montheat monthhse, by (hhid2004);

** Reset flags to 0/1                                                   **;

replace flagyreg = (flagyreg > 0) ;
replace flagnet  = (flagnet  > 0) ;
replace flaggrs  = (flaggrs  > 0) ;
replace flaghse  = (flaghse  > 0) ;

sort hhid2004 ;
merge hhid2004 using $IN\cover ;
assert _merge == 2 | _merge ==3 ;
drop _merge ;

program define fillzero ;

 while "`1'"~="" { ;
   replace `1'=0 if `1'==. ;
   
   mac shift         ;
   
   }                 ;

end ;


fillzero hhnwage hhgwage flagyreg flaghse monthtvl montheat monthhse ;


lab data "2004 Household Regular Wage Income";

label var hhnwage  "04: HH Month Net Wage + Bonus";
label var hhgwage  "04: HH Month Gross Wage + Bonus" ;
label var flagyreg "04: (1) Net pay imputed- regn" ;
label var flaghse  "04: (1) if Hse subsidy imputed" ;
label var monthtvl "04: Avg month transport subsidy" ;
label var montheat "04: Avg month food subsidy";
label var monthhse "04: Avg month housing subsidy";

drop flagnet flaggrs ;

notes drop _dta ;

keep hhid2004 hhnwage hhgwage flagyreg monthtvl montheat monthhse flaghse ;

order hhid2004 hhnwage hhgwage flagyreg monthtvl montheat monthhse flaghse ;

sort hhid2004;
save $OUT\hhyreg, replace;  

desc ;
summ ;

erase $OUT\step1.dta ;

exit ;

