#delimit ;
***************************************************************
*                                                             *
*    Name    : FOODEXP.DO               V : 01                *
*    Date    : 12 OCT 2004                                    *
*    Infile  : SECTION 3.1                                    *
*    Outfile : FOODEXP                                        *
*                                                             *
*    OBJECTIVE: Calculate total household monthly             *  
*               expenditure on food (Section 3)               *
*                                                             *
*               Cluster & item medians used to impute         *
*               missing values unless otherwise noted.        *
*               Medians are not calc by race and cluster      *
*               (as in the past) as only 2 clusters           *
*               have both African and Indian residents        *
*               and even then too small numbers of both races *
*               (There are 3 Africans in cluster 62 and 1     *
*               African in cluster 67)                        *
***************************************************************;

capture log cl;
set more 1;

global IN  = "C:\DATA\KIDS3\version1.1";
global OUT = "C:\DATA\KIDS3\version1.1\constructed";

use $IN\section3.dta, clear ;         

rename clust clustnum;

** Construct 0/1 flag for missing values                                **;;

gen byte flagfood = ( purchasd < 0|purchasd==. ) ;

**  Calculate cluster medians of non-zero purchases              **;;

egen medpval = median(purchasd) if purchasd>0, by(foodcode clustnum) ;  
egen medval  = min(medpval),                   by(foodcode clustnum) ;

** List the households and items with missing values and the            **
** corresponding median values for imputations                          **;;

li hhid2004 foodcode medval if flagfood, noobs nolabel ;

** Replace missing observations with cluster medians             **;;

replace purchasd = medval if flagfood ;

** Set missing own production, gifts and food payments to zero and flag **;

replace flagfood=1 if gift<0|payment<0|ownprod<0;
replace gift=0 if gift<0;
replace ownprod=0 if ownprod<0;
replace payment=0 if payment<0;

** Calculate total expenditures for each food item                      **;;

gen mxtfood = purchasd + gift + payment + ownprod ;

** Calculate total expenditures for food categories                     **;;

** Assignments to food type categories made as follows                  **
** note that tinned fruit is code 40 - misprint on Q                    **;
** note that food received as guests is code 41 - misprint on Q         **;
**
**      Food type       name            codes included
**      ---------       ----            --------------
**
**      Grains          grain           1 2 3 4 5 6
**      Fruit/Veggies   fruit_veg       7 8 9 10 23 24 25 26 27 33 38 39 40
**      Oil/Fats        oils            11 12
**      Dairy           dairy           13 15 16 36 35
**      Sugar           sugar           17
**      Meat/Fish       meat            18 19 20 21 22 32 37
**      Other           other           14 28 29 31 34
**                                                                      **;;

gen mxgrain   = mxtfood if  foodcode<=6;

gen mxfruit_veg   = mxtfood if (foodcode>= 7 & foodcode<=10)
                    |(foodcode>=23 & foodcode<=27)| foodcode==33 | foodcode==38| foodcode==39| foodcode==40;

gen mxoils    = mxtfood if (foodcode==11 | foodcode==12) ;

gen mxdairy   = mxtfood if (foodcode==13 | foodcode==15 | foodcode==16| foodcode==36| foodcode==35) ;

gen mxsugar   = mxtfood if  foodcode==17 ;

gen mxmeat = mxtfood if (foodcode>=18 & foodcode<=22)| foodcode==32 | foodcode==37;

gen mxother   = mxtfood if (foodcode==14 | foodcode==28 | foodcode==29 |
                            foodcode==31 | foodcode==34) ;

gen mealgot   = mxtfood if foodcode==41 ;
gen mealgave  = mxtfood if foodcode==30 ;

collapse (sum) mxpurch=purchasd mxgift=gift mxpay=payment
               mxownprd=ownprod mxgrain mxfruit_veg  mxoils mxdairy
               mxsugar mxmeat mxother flagfood mxtfood 
               mealgave mealgot
               ,  by(hhid2004) ;

** Verify calculations                                                  **;;

gen check = mxgrain + mxfruit_veg + mxoils + mxdairy + mxsugar + mxmeat + 
            mxother + mealgot + mealgave;  
    

count if (mxtfood>check+0.1)|(mxtfood<check-0.1) ; ** +/- 9.1 included because of small rounding errors;
drop check ;


** Calculate % Food shares                                              **;;

gen sxgrain = 100 * mxgrain / mxtfood if mxtfood > 0 ;
gen sxfruit_veg = 100 * mxfruit_veg / mxtfood if mxtfood > 0 ;
gen sxoils  = 100 * mxoils  / mxtfood if mxtfood > 0 ;
gen sxdairy = 100 * mxdairy / mxtfood if mxtfood > 0 ;
gen sxsugar = 100 * mxsugar / mxtfood if mxtfood > 0 ;
gen sxmeat = 100 * mxmeat / mxtfood if mxtfood > 0 ;
gen sxother = 100 * mxother / mxtfood if mxtfood > 0 ;

** Label Variables                                                      **;;

label data "1998 Food Expenditures" ;

label var mxtfood   "2004: Tot month food exp";
label var mxpurch   "2004: Tot month food purchased";
label var mxgift    "2004: Tot month food gifts";
label var mxpay     "2004: Tot month food payment";
label var mxownprd  "2004: Tot month food production";
label var mxgrain   "2004: Tot month exp: grains";
label var mxfruit_veg   "2004: Tot month exp: fruit/veg";
label var mxoils    "2004: Tot month exp: butter/oil";
label var mxdairy   "2004: Tot month exp: dairy";
label var mxsugar   "2004: Tot month exp: sugar";
label var mxmeat   "2004: Tot month exp: meat";
label var mxother   "2004: Tot month exp: other + meals gave/got";
label var mealgave  "2004: Tot month exp: meals given" ;
label var mealgot   "2004: Tot month exp: meals receivd" ;
label var flagfood  "2004: (1) if food item imputed";
label var sxgrain   "2004: % Food share : grains";
label var sxfruit_veg   "2004: % Food share : fruit/veg";
label var sxoils    "2004: % Food share : butter/oil";
label var sxdairy   "2004: % Food share : dairy";
label var sxsugar   "2004: % Food share : sugar";
label var sxmeat   "2004: % Food share : meat";
label var sxother   "2004: % Food share : other";

*log using query\foodexp.log, t replace;
list hhid2004 mxgrain mxfruit mxoils mxdairy mxsugar mxmeat mxother if sxgrain>90 & sxgrain<=100;
list hhid2004 mxgrain mxfruit mxoils mxdairy mxsugar mxmeat mxother if sxfruit>75 & sxfruit<=100;
list hhid2004 mxgrain mxfruit mxoils mxdairy mxsugar mxmeat mxother if sxoils>50 & sxoils<=100;
list hhid2004 mxgrain mxfruit mxoils mxdairy mxsugar mxmeat mxother if sxdairy>50 & sxdairy<=100;
list hhid2004 mxgrain mxfruit mxoils mxdairy mxsugar mxmeat mxother if sxsugar>50 & sxsugar<=100;
list hhid2004 mxgrain mxfruit mxoils mxdairy mxsugar mxmeat mxother if sxmeat>50 & sxmeat<=100;
list hhid2004 mxgrain mxfruit mxoils mxdairy mxsugar mxmeat mxother if sxother>50 & sxother<=100;
*log close;
sort hhid2004 ;

save $OUT\foodexp, replace ;

desc ;

** ONE CASE WHERE HH DID NOT BUY ANY FOOD, SO ALL RATIOS ARE MISSING **;

summ ;

exit ;
