#delimit ;;
*************************************************************
*                                                           *
*    Name    : REGEXP.DO                  V : 01            *
*    Date    : 11 NOV 2004                                  *
*    Infile  : SECTION 4.1                                  *
*    Outfile : REGNFEXP                                     *
*                                                           *
*    OBJECTIVE: Calculate total household monthly           *
*               expenditure on regular non-food commodities *
*               including energy (Section 4.1)              *
*                                                           *
*               Cluster, item medians used to impute        *
*               missing values unless otherwise noted       *
*                                                           *
*************************************************************;;

clear;
capture log close;
capture program drop fillmedn;

global IN  = "c:\data\kids3\version1.1";
global OUT = "c:\data\kids3\version1.1\constructed";

use $IN\roster2004.dta, clear ;
rename race q1;
egen race=max(q1), by(hhid2004);
egen race2=min(q1), by(hhid2004);  ** there are some hh with Coloured & White members -
                                we want to assign hhs as African or Indian wherever possible;

replace race=race2 if race==2|race==4;

replace race=1 if hhid2004==205008040;  ** hh where all members are african except one person with missing code;

collapse race, by(hhid2004);
sort hhid2004;
save $OUT\race_hh, replace;

use $IN\section4_1.dta, clear ;
sort hhid2004;
merge hhid2004 using $OUT\race_hh;
tab _m; drop _merge;
rename cluster clustnum;

** Construct 0/1 flag for missing values                                **;;

gen byte flagreg = ( rnfs_a < 0 ) ;

** Calculate cluster medians of nonzero purchases                **;;

egen medpval= median(rnfs_a) if (rnfs_a>0), by(rnfs_c clustnum) ;

egen medval = min(medpval),                 by(rnfs_c clustnum) ; 

** there are 19 cases where the median values are missing - for these use medians by race **;

egen medval_r= median(rnfs_a) if (rnfs_a>0), by(rnfs_c race) ;

egen medrval = min(medpval),                 by(rnfs_c race) ; 

** List the households and items with missing values and the            **
** corresponding median values for imputations                          **;;

li hhid2004 rnfs_c medval if flagreg , noobs ;

** IN SOME CASES, THE MEDIANS SEEM VERY HIGH OR VERY LOW - IN THESE CASES USE MEDIANS BY RACE **;

replace medval=. if medval>500|medval<2;

li hhid2004 rnfs_c medval if flagreg & medval>500 & medval!=., noobs ;

li hhid2004 rnfs_c medrval if flagreg & medval==., noobs ;

replace medval=medrval if flagreg & medval==.;

drop medrval medpval medval_r;

**----------------------------------------------------------------------**
** Replace missing observations with cluster medians                    **
**----------------------------------------------------------------------**;;


** (1) Water, Electricity, and Municipal Rates measures                 **;;

gen     energy1 = rnfs_a if rnfs_c==14 & flagreg == 0 ;
replace energy1 = medval if rnfs_c==14 & flagreg == 1 ;

gen     water = rnfs_a if rnfs_c == 15 & flagreg == 0 ;
replace water = medval if rnfs_c == 15 & flagreg == 1 ;

gen     elec = rnfs_a  if rnfs_c == 16 & flagreg == 0 ;
replace elec = medval  if rnfs_c == 16 & flagreg == 1 ;

gen     muni = rnfs_a  if rnfs_c == 17 & flagreg == 0 ;
replace muni = medval  if rnfs_c == 17 & flagreg == 1 ;

** Calculate combined energy, water, municipal rates at household level **;;

** Combined Expenditure (rnfs_c=14)                                     **;;

egen energy1h = sum(energy1), by (hhid2004) ;

** Components of expenditure (rnfs_c=15,16,17)                          **;;

egen water_h  = sum(water), by (hhid2004) ;
egen elec_h   = sum(elec) , by (hhid2004) ;
egen muni_h   = sum(muni) , by (hhid2004) ;

gen add       = water_h + elec_h + muni_h ;

** Construct variable MXEWR which is sum of household expenditure on    **
** water + electricity + municipal rates regardless of whether reported **
** as combined (rnfs_c==14) or individual categories (rnfs_c= 15-17)    **;;

gen mxewr     = add ;
replace mxewr = energy1h if add == 0 ;

drop energy1* water* elec* muni* ;;;


** (2) Other expenditures                        **;;

** Median for cluster with missing rnfs_c=18 is also missing so fill in **
** with overall median for rnfs_c=18 which is 30 Rand                   **;;

replace rnfs_a = 30 if rnfs_c == 18 & flagreg == 1 & clustnum == 73 ;

** The following program constructs temporary variables to calculate    **
** household level expenditures, replacing missing values with medians  **;;

program define fillmedn ;

 while "`1'"~="" { ;

   gen com`1'=rnfs_a       if rnfs_c==`1' & flagreg==0 ;
   replace com`1' = medval if rnfs_c==`1' & flagreg==1 ;
 
   mac shift         ;
   
   }                 ;

end ;


fillmedn 1 2 3 4 5 6 7 8 9 10 11 12 13 18 ;

                                   
** Calculate the other non-food expenditures at the household level     ** 
** using the temporary variables constructed above.                     **
** Note: The "egen & summ" command turns missing values into zeros      **;;

egen mxcig   = sum(com1) , by (hhid2004) ;
egen mxalc   = sum(com2) , by (hhid2004) ;
egen mxent   = sum(com3) , by (hhid2004) ;
egen mxpcare = sum(com4) , by (hhid2004) ;
egen mxnews  = sum(com5) , by (hhid2004) ;
egen mxtel   = sum(com6) , by (hhid2004) ;
egen mxcar   = sum(com7) , by (hhid2004) ;
egen mxtran1  = sum(com8) , by (hhid2004) ;                  
egen mxwash  = sum(com9) , by (hhid2004) ;
egen mxchil  = sum(com10), by (hhid2004) ;
egen mxdues  = sum(com11), by (hhid2004) ;
egen mxdon   = sum(com12), by (hhid2004) ;
egen mxhelp  = sum(com13), by (hhid2004) ;
egen mxener  = sum(com18), by (hhid2004) ;

** Calculate total monthly regular non-food expenditure for household   **;;

gen mxtot   = mxcig + mxalc + mxent + mxpcare + mxnews + mxtel + mxcar + 
              mxtran1 + mxwash + mxchil + mxdues + mxdon + mxhelp + 
              mxener + mxewr ;

** Label Variables                                                      **;;

label data "1998 Regular Non-Food Expenditures" ;

label var mxcig   "04: Month exp: Cigs & Tobacco" ;
label var mxalc   "04: Month exp: Alcohol" ;
label var mxent   "04: Month exp: Entertainment" ;
label var mxpcare "04: Month exp: Personal Care" ;
label var mxnews  "04: Month exp: Newspapers" ;
label var mxtel   "04: Month exp: Telephone" ;
label var mxcar   "04: Month exp: Vehicle" ;
label var mxtran1 "04: Month exp: Transportation" ;
label var mxwash  "04: Month exp: Washing Supplies" ;
label var mxchil  "04: Month exp: Day Care" ;
label var mxdues  "04: Month exp: Dues" ;
label var mxdon   "04: Month exp: Donations" ;
label var mxhelp  "04: Month exp: Household Help" ;
label var mxener  "04: Month exp: Other Energy" ;
label var mxewr   "04: Month exp: water, elec & municipal rates" ;
label var mxtot   "04: Month exp: Total regular non-food" ;
label var flagreg "04: (1) if any exp item imputed" ;

  
** Construct household level file, sort to retain non-zero flags        **;;

drop rnfs_c rnfs_a medval com* add clustnum ;
gsort + hhid2004 - flag ;
quietly by hhid2004: keep if _n==1 ;

notes drop _dta ;
order hhid2004 mxewr mxcig mxalc mxent mxpcare mxnews mxtel mxcar mxtran1
 mxwash mxchil mxdues mxdon mxhelp mxener mxtot flag ;
sort hhid2004 ;
save $OUT\regnfexp, replace ;         

